@@ -34,7 +34,7 @@ typedef void* (*hook)(void*);
  * Derivations of this class can be considered as a link
  * between a slot and the functor that the slot should
  * execute in operator(). This link is needed because in
- * libsigc++2 the slot doesn't necessarily have exactly the
+ * libsigc++ the slot doesn't necessarily have exactly the
  * same function signature as the functor, thus allowing for
  * implicit conversions.
  *
@@ -179,23 +179,20 @@ struct SIGC_API slot_do_unbind
 
 /** @defgroup slot Slots
  * Slots are type-safe representations of callback methods and functions.
- * A Slot can be constructed from any function object or function, regardless of
+ * A slot can be constructed from any function object or function, regardless of
  * whether it is a global function, a member method, static, or virtual.
  *
- * Use the sigc::mem_fun() and sigc::ptr_fun() template functions to get a sigc::slot, like so:
+ * @section slots-creating Creating Slots
  *
+ * Use the sigc::mem_fun() or sigc::ptr_fun() template functions to get a sigc::slot, like so:
  * @code
  * sigc::slot<void, int> sl = sigc::mem_fun(someobj, &SomeClass::somemethod);
  * @endcode
- *
  * or
- *
  * @code
  * sigc::slot<void, int> sl = sigc::ptr_fun(&somefunction);
  * @endcode
- *
- * or
- *
+ * or, in gtkmm,
  * @code
  * m_Button.signal_clicked().connect( sigc::mem_fun(*this, &MyWindow::on_button_clicked) );
  * @endcode
@@ -204,6 +201,29 @@ struct SIGC_API slot_do_unbind
  *
  * You can also pass slots as method parameters where you might normally pass a function pointer.
  *
+ * @section slots-auto-disconnect Member Methods and Automatic Disconnection
+ *
+ * See @ref mem_fun "sigc::mem_fun()" about deriving from sigc::trackable to prevent member
+ * methods from being called after the instance has been destroyed.
+ *
+ * @section slots-auto auto
+ *
+ * sigc::mem_fun() and sigc::ptr_fun() return functors, but those functors are
+ * not slots.
+ * @code
+ * sigc::slot<void, int> sl = sigc::mem_fun(someobj, &SomeClass::somemethod);
+ * @endcode
+ * is not equivalent to
+ * @code
+ * auto sl = sigc::mem_fun(someobj, &SomeClass::somemethod); // Not a slot!
+ * @endcode
+ *
+ * If you don't explicitly use a sigc::slot then the slot could call a method
+ * on an instance after it has been destroyed even if the method is in a class
+ * that derives from sigc::trackable.
+ *
+ * @section slots-with-lambdas C++ Lambdas
+ *
  * A C++11 lambda expression is a functor (function object). It is automatically
  * wrapped in a slot, if it is connected to a signal.
  * @code
@@ -277,7 +297,7 @@ public:
    *  do_something()
    * @endcode
    */
-  operator bool() const noexcept;
+  explicit operator bool() const noexcept;
 
   /** Sets the parent of this slot.
    * This function is used by signals to register a notification callback.
